index\_calculator.postprocessing
================================

.. currentmodule:: index_calculator

.. autoclass:: postprocessing


   .. automethod:: __init__


   .. rubric:: Methods

   .. autosummary::

      ~postprocessing.__init__
      ~postprocessing.postprocessing
